import { defineStore } from "pinia";
import { WorkflowService } from "@/client/workflow";
import type { WorkflowVersionReduced } from "@/client/workflow";
import type { WorkflowOut } from "@/client/workflow";

export const useWorkflowStore = defineStore({
  id: "workflows",
  state: () =>
    ({
      workflows: [],
    } as {
      workflows: WorkflowOut[];
    }),
  getters: {
    latestVersion(): (
      workflowId: string
    ) => WorkflowVersionReduced | undefined {
      return (workflowId) => {
        const workflow = this.workflows.find(
          (w) => workflowId == w.workflow_id
        );
        return workflow?.versions[
          Math.max(workflow?.versions?.length - 1 ?? 0, 0)
        ];
      };
    },
  },
  actions: {
    fetchWorkflows(
      onFulfilled:
        | ((workflows: WorkflowOut[]) => void)
        | null
        | undefined = null,
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      onRejected: ((reason: any) => void) | null | undefined = null,
      onFinally: (() => void) | null | undefined = null
    ) {
      WorkflowService.workflowListWorkflows()
        .then((workflows) => {
          this.workflows = workflows;
          onFulfilled?.(workflows);
        })
        .catch(onRejected)
        .finally(onFinally);
    },
  },
});
